.plonetoolbar-contenttype .contenttype-faq::before,
.plonetoolbar-contenttype .contenttype-faq-item::before {
    content: '';
    width: 14px;
    height: 14px;
    opacity: .85;
}
.plonetoolbar-contenttype .contenttype-faq::before {
    background-image: url('++resource++collective.faq/faq.svg');
}
.plonetoolbar-contenttype .contenttype-faq-item::before {
    background-image: url('++resource++collective.faq/faq-item.svg');
}
.faq {
    padding: 0;
}
#content .faq,
#content .faq-nested {
    list-style: none;
    margin: 0;
}
.faq .faq-detailed-question,
.faq .faq-nested-description {
    font-weight: normal;
}
.faq .glyphicon:before {
    content: ''
}
.faq .glyphicon {
    display: inline-block;
    width: 9px;
    height: 9px;
}
.faq .glyphicon-plus {
    background: url('++resource++collective.faq/sprite.png') 0 0;
}
.faq .glyphicon-minus {
    background: url('++resource++collective.faq/sprite.png') -9px 0;
}
.faq .faq-question,
.faq .faq-nested-title {
    font-weight: bold;
}
.faq .faq-detailed-question {
    margin-left: 1em;
}
#content .faq .faq-li-question {
    margin-bottom: 1em;
}
#content .faq .faq-nested {
    margin-top: 1em;
}
.faq .glyphicon-plus + .faq-question + .faq-answer,
.faq .glyphicon-plus + .faq-question + .faq-detailed-question + .faq-answer {
    display: none;
}
.faq .faq-answer {
    margin: 1em;
    padding: 0.5em;
    border: thin dotted;
    background-color: #EFF7FF;
}
h2 .faq-nested-title {
    font-weight: normal !important;
}
